@@ -1,12 +1,13 @@
 #' @title Model Ranking Plot
 #'
-#' @description Radar plot with model score. score are scaled to [0,1], each score is inversed and divided by maximum score value.
+#' @description Radar plot with model score. score are scaled to \code{[0,1]},
+#' each score is inversed and divided by maximum score value.
 #'
-#' @param object An object of class 'auditor_model_performance' created with \code{\link{model_performance}} function.
-#' @param ... Other auditor_model_performance' objects to be plotted together.
+#' @param object An object of class \code{auditor_model_performance} created with \code{\link{model_performance}} function.
+#' @param ... Other \code{auditor_model_performance} objects to be plotted together.
 #' @param verbose Logical, indicates whether values of scores should be printed.
 #'
-#' @return ggplot object
+#' @return A ggplot object.
 #'
 #' @examples
 #' dragons <- DALEX::dragons[1:100, ]
@@ -14,25 +15,20 @@
 #' # fit a model
 #' model_lm <- lm(life_length ~ ., data = dragons)
 #'
-#' # use DALEX package to wrap up a model into explainer
-#' exp_lm <- DALEX::explain(model_lm, data = dragons, y = dragons$life_length)
+#' lm_audit <- audit(model_lm, data = dragons, y = dragons$life_length)
 #'
 #' # validate a model with auditor
-#' library(auditor)
-#' mp_lm <- model_performance(exp_lm)
+#' mp_lm <- model_performance(lm_audit)
 #'
 #'
 #' library(randomForest)
 #' model_rf <- randomForest(life_length~., data = dragons)
-#' exp_rf <- DALEX::explain(model_rf, data = dragons, y = dragons$life_length)
-#' mp_rf <- model_performance(exp_rf)
+#' rf_audit <- audit(model_rf, data = dragons, y = dragons$life_length)
+#' mp_rf <- model_performance(rf_audit)
 #'
 #' # plot results
 #' plot_radar(mp_lm, mp_rf)
 #'
-#' @import ggplot2
-#' @import scales
-#'
 #' @export
 plot_radar <- function(object, ..., verbose = TRUE) {
 
@@ -79,7 +75,7 @@ plot_radar <- function(object, ..., verbose = TRUE) {
 #' @rdname plot_radar
 #' @export
 plotModelRanking <- function(object, ..., verbose = TRUE) {
-  message("Please note that 'plotModelRanking()' is now deprecated, it is better to use 'plot_radar()' instead.")
+  warning("Please note that 'plotModelRanking()' is now deprecated, it is better to use 'plot_radar()' instead.")
   plot_radar(object, ..., verbose = verbose)
 }
 
